import { Component, OnInit, Input, OnChanges } from '@angular/core';
import { Router } from '@angular/router';
import { MetaCrawler } from '../../../../meta/crawler/model/MetaCrawler';

import { Store, select } from '@ngrx/store';
import { RPCError } from 'packages/core/rpc/error';
import * as ListStore from 'packages/meta/crawler-input-item/store/list';
import { ReadCrawlerInputItemSelector } from 'packages/meta/crawler-input-item/store';
import { MetaCrawlerInputItem } from '../../../../meta/crawler-input-item/model/MetaCrawlerInputItem';


@Component({
  selector: 'of-crawler-auth',
  templateUrl: './crawler-auth.component.html',
  styleUrls: ['./crawler-auth.component.scss']
})
export class CrawlerAuthComponent implements OnInit, OnChanges {

  inputItems$ = this.listStore.pipe(select(ReadCrawlerInputItemSelector.select('inputs')));
  inputItems: MetaCrawlerInputItem[];

  @Input() selectedCrawler: MetaCrawler;
  constructor(
    private router: Router,
    private listStore: Store<ListStore.State>,
  ) { }

  ngOnInit() {
    this.inputItems$.subscribe(
      (list: MetaCrawlerInputItem[]) => {
        if (list !== null) {
          this.inputItems = list;
          this.generateAuthComponent();
        }
      },
      (error: RPCError) => {
        console.log(error.response.message);
      }
    );
  }

  ngOnChanges() {
    if (this.selectedCrawler === null) { return; }
    this.getCrawlerAuthInputItems();
  }

  getCrawlerAuthInputItems() {
    this.listStore.dispatch(new ListStore.ReadAll(this.selectedCrawler));
  }

  generateAuthComponent() {
    // inputType: MetaInputType;
    // crawler: MetaCrawler;
    // description: string;
    // name: string;
    // createDate: Date;
    // required: boolean;
    // defaultValue: string;
    // pattern: string;
    // keyName: string;
    // keyValue: string;
    for (const inputItem of this.inputItems) {
      const typeId = inputItem.inputType.id;
      switch (typeId) {
        case 1: // TEXT_TYPE
          break;
        case 2: // PASSWORD_TYPE
          break;
        case 3: // NUMBER_TYPE
          break;
        case 4: // BOOLEAN_TYPE
          break;
        case 5: // SELECT_TYPE
          break;
        default:
          break;
      }
    }
  }
}
